@@ -1,5 +1,5 @@
 /****************************************************************************
-** $Id: qt/property.cpp   3.2.2   edited Jun 5 05:35 $
+** $Id: qt/property.cpp   3.2.3   edited Oct 22 19:10 $
 **
 ** Implementation of QMakeProperty class.
 **
@@ -88,7 +88,7 @@ QMakeProperty::value(QString v, bool just_check)
 	return qInstallPathData();
 #endif
     } else if(v == "QMAKE_MKSPECS") {
-	return qmake_mkspec_paths().join(":");
+	return qmake_mkspec_paths().join(Option::target_mode == Option::TARG_WIN_MODE ? ";" : ":");
     } else if(v == "QMAKE_VERSION") {
 	return qmake_version();
     }
