@@ -1,5 +1,5 @@
 /****************************************************************************
-** $Id: qt/qevent.cpp   3.2.2   edited Oct 1 14:21 $
+** $Id: qt/qevent.cpp   3.2.3   edited Nov 3 10:05 $
 **
 ** Implementation of event classes
 **
@@ -474,10 +474,10 @@ Qt::ButtonState QMouseEvent::stateAfter() const
 
     \ingroup events
 
-    Wheel events occur when a mouse wheel is turned while the widget
-    has focus. The rotation distance is provided by delta(). The
-    functions pos() and globalPos() return the mouse pointer location
-    at the time of the event.
+    Wheel events are sent to the widget under the mouse, and if that widget
+    does not handle the event they are sent to the focus widget. The rotation 
+    distance is provided by delta(). The functions pos() and globalPos() return 
+    the mouse pointer location at the time of the event.
 
     A wheel event contains a special accept flag that indicates
     whether the receiver wants the event. You should call
@@ -2132,8 +2132,8 @@ QTabletEvent::QTabletEvent( Type t, const QPoint &pos, const QPoint &globalPos,
     QCustomEvent is a generic event class for user-defined events.
     User defined events can be sent to widgets or other QObject
     instances using QApplication::postEvent() or
-    QApplication::sendEvent(). Subclasses of QWidget can easily
-    receive custom events by implementing the QWidget::customEvent()
+    QApplication::sendEvent(). Subclasses of QObject can easily
+    receive custom events by implementing the QObject::customEvent()
     event handler function.
 
     QCustomEvent objects should be created with a type ID that
