@@ -1,5 +1,5 @@
 /****************************************************************************
-** $Id: qt/qmime.cpp   3.2.2   edited Jun 30 12:55 $
+** $Id: qt/qmime.cpp   3.2.3   edited Oct 31 11:27 $
 **
 ** Implementation of MIME support
 **
@@ -283,7 +283,8 @@ QMimeSource* QMimeSourceFactory::dataInternal(const QString& abs_name, const QMa
 	    f.readBlock(ba.data(), ba.size());
 	    QStoredDrag* sr = new QStoredDrag( mimetype );
 	    sr->setEncodedData( ba );
-	    r = sr;
+	    delete d->last;
+	    d->last = r = sr;
 	}
     }
 
@@ -399,9 +400,6 @@ const QMimeSource* QMimeSourceFactory::data(const QString& abs_name) const
 	r = (QMimeSource*)defaultFactory()->data( abs_name );
     }
 
-
-    delete d->last;
-    d->last = r;
     return r;
 }
 
