@@ -1,5 +1,5 @@
 /****************************************************************************
-** $Id: qt/qmovie.cpp   3.2.2   edited May 13 09:08 $
+** $Id: qt/qmovie.cpp   3.2.3   edited Oct 14 16:57 $
 **
 ** Implementation of movie classes
 **
@@ -351,22 +351,6 @@ void QMoviePrivate::updatePixmapFromImage(const QPoint& off,
     if (mypixmap.width() != gimg.width() || mypixmap.height() != gimg.height())
 	mypixmap.resize(gimg.width(), gimg.height());
 
-    if (bg.isValid()) {
-	QPainter p;
-	p.begin(&mypixmap);
-	p.fillRect(area, bg);
-	p.end();
-    } else {
-	if (gimg.hasAlphaBuffer()) {
-	    // Resize to size of image
-	    if (mymask.isNull()) {
-		mymask.resize(gimg.width(), gimg.height());
-		mymask.fill( Qt::color1 );
-	    }
-	}
-	mypixmap.setMask(QBitmap()); // Remove reference to my mask
-    }
-
     // Convert to pixmap and paste that onto myself
     QPixmap lines;
 
@@ -377,18 +361,34 @@ void QMoviePrivate::updatePixmapFromImage(const QPoint& off,
         QString key;
         key.sprintf( "%08lx:%04d", ( long )this, framenumber );
         if ( !QPixmapCache::find( key, lines ) ) {
-            lines.convertFromImage(img);
+            lines.convertFromImage(img, Qt::ColorOnly);
             QPixmapCache::insert( key, lines );
             dirty_cache = TRUE;
         }
     } else
 #endif
     {
-        lines.convertFromImage( img );
+        lines.convertFromImage(img, Qt::ColorOnly);
     }
 
-    copyBlt( &mypixmap, area.left(), area.top(),
-	     &lines, off.x(), off.y(), area.width(), area.height() );
+    if (bg.isValid()) {
+	QPainter p;
+	p.begin(&mypixmap);
+	p.fillRect(area, bg);
+	p.drawPixmap(area, lines);
+	p.end();
+    } else {
+	if (gimg.hasAlphaBuffer()) {
+	    // Resize to size of image
+	    if (mymask.isNull()) {
+		mymask.resize(gimg.width(), gimg.height());
+		mymask.fill( Qt::color1 );
+	    }
+	}
+	mypixmap.setMask(QBitmap()); // Remove reference to my mask
+	copyBlt( &mypixmap, area.left(), area.top(),
+		 &lines, off.x(), off.y(), area.width(), area.height() );
+    }
 
 #ifdef Q_WS_QWS
     if(display_widget) {
