@@ -1,5 +1,5 @@
 /****************************************************************************
-** $Id: qt/qscriptengine_x11.cpp   3.2.2   edited Oct 10 00:37 $
+** $Id: qt/qscriptengine_x11.cpp   3.2.3   edited Oct 24 08:32 $
 **
 ** Continuation of middle eastern languages
 **
@@ -1533,7 +1533,7 @@ static void indic_shape_syllable( int script, const QString &string, int from, i
 
 	openType->applyGSUBFeature(FT_MAKE_TAG( 'c', 'c', 'm', 'p' ));
 
-	where[0] = (from == 0 || !string.unicode()[from-1].isLetter());
+	where[0] = TRUE;
 	openType->applyGSUBFeature(FT_MAKE_TAG( 'i', 'n', 'i', 't' ), where);
 	openType->applyGSUBFeature(FT_MAKE_TAG( 'n', 'u', 'k', 't' ));
 
@@ -2665,16 +2665,16 @@ static void hangul_shape_syllable( const QString &string, int from, int syllable
     if (syllableLength == 2) {
 	int LIndex = ch[0].unicode() - Hangul_LBase;
 	int VIndex = ch[1].unicode() - Hangul_VBase;
-	if (LIndex > 0 && LIndex < Hangul_LCount &&
-	    VIndex > 0 && VIndex < Hangul_VCount)
+	if (LIndex >= 0 && LIndex < Hangul_LCount &&
+	    VIndex >= 0 && VIndex < Hangul_VCount)
 	    composed = (LIndex * Hangul_VCount + VIndex) * Hangul_TCount + Hangul_SBase;
     } else if (syllableLength == 3) {
 	int LIndex = ch[0].unicode() - Hangul_LBase;
 	int VIndex = ch[1].unicode() - Hangul_VBase;
 	int TIndex = ch[1].unicode() - Hangul_TBase;
-	if (LIndex > 0 && LIndex < Hangul_LCount &&
-	    VIndex > 0 && VIndex < Hangul_VCount &&
-	    TIndex > 0 && TIndex < Hangul_TCount )
+	if (LIndex >= 0 && LIndex < Hangul_LCount &&
+	    VIndex >= 0 && VIndex < Hangul_VCount &&
+	    TIndex >= 0 && TIndex < Hangul_TCount )
 	    composed = (LIndex * Hangul_VCount + VIndex) * Hangul_TCount + TIndex + Hangul_SBase;
     }
 
@@ -2723,7 +2723,7 @@ static void hangul_shape_syllable( const QString &string, int from, int syllable
 	};
 	const int *f = features;
 	while (*f)
-	    openType->applyGSUBFeature(*f);
+	    openType->applyGSUBFeature(*f++);
 	openType->applyGPOSFeatures();
 
 	GlyphAttributes *glyphAttrs = engine->glyphAttributes(si)+si->num_glyphs;
@@ -2760,7 +2760,7 @@ static void hangul_shape_syllable( const QString &string, int from, int syllable
 	advance_t *advances = engine->advances(si)+si->num_glyphs;
 	GlyphAttributes *glyphAttributes = engine->glyphAttributes(si)+si->num_glyphs;
 
-	int error = si->fontEngine->stringToCMap(ch, len, glyphs, advances, &len,
+	int error = si->fontEngine->stringToCMap(chars, len, glyphs, advances, &len,
 						 (si->analysis.bidiLevel %2));
 	assert (!error);
 
