@@ -1,5 +1,5 @@
 /****************************************************************************
-** $Id: qt/qwidget.h   3.1.2   edited Feb 17 06:11 $
+** $Id: qt/qwidget.h   3.2.3   edited Nov 4 22:34 $
 **
 ** Definition of QWidget class
 **
@@ -116,7 +116,7 @@ class Q_EXPORT QWidget : public QObject, public QPaintDevice
     Q_PROPERTY( bool focus READ hasFocus )
     Q_PROPERTY( bool updatesEnabled READ isUpdatesEnabled WRITE setUpdatesEnabled DESIGNABLE false )
     Q_PROPERTY( bool visible READ isVisible )
-    Q_PROPERTY( QRect visibleRect READ visibleRect )
+    Q_PROPERTY( QRect visibleRect READ visibleRect ) // obsolete
     Q_PROPERTY( bool hidden READ isHidden WRITE setHidden DESIGNABLE false SCRIPTABLE false )
     Q_PROPERTY( bool shown READ isShown WRITE setShown DESIGNABLE false SCRIPTABLE false )
     Q_PROPERTY( bool minimized READ isMinimized )
@@ -128,6 +128,7 @@ class Q_EXPORT QWidget : public QObject, public QPaintDevice
     Q_PROPERTY( bool acceptDrops READ acceptDrops WRITE setAcceptDrops )
     Q_PROPERTY( bool autoMask READ autoMask WRITE setAutoMask DESIGNABLE false SCRIPTABLE false )
     Q_PROPERTY( bool customWhatsThis READ customWhatsThis )
+    Q_PROPERTY( bool inputMethodEnabled READ isInputMethodEnabled WRITE setInputMethodEnabled DESIGNABLE false SCRIPTABLE false )
 
 public:
     Q_EXPLICIT QWidget( QWidget* parent=0, const char* name=0, WFlags f=0 );
@@ -293,8 +294,8 @@ public:
 	NoFocus = 0,
 	TabFocus = 0x1,
 	ClickFocus = 0x2,
-	StrongFocus = 0x3,
-	WheelFocus = 0x7
+	StrongFocus = TabFocus | ClickFocus | 0x8,
+	WheelFocus = StrongFocus | 0x4
     };
 
     bool		isActiveWindow() const;
@@ -308,6 +309,8 @@ public:
     virtual void	setFocusProxy( QWidget * );
     QWidget *		focusProxy() const;
 
+    void setInputMethodEnabled( bool b );
+    bool isInputMethodEnabled() const;
     // Grab functions
 
     void		grabMouse();
@@ -370,7 +373,7 @@ public:
     bool		isVisible()	const;
     bool		isVisibleTo(QWidget*) const;
     bool		isVisibleToTLW() const; // obsolete
-    QRect		visibleRect() const;
+    QRect		visibleRect() const; // obsolete
     bool 		isHidden() const;
     bool 		isShown() const;
     bool		isMinimized() const;
@@ -384,6 +387,8 @@ public:
     void 		setSizePolicy( QSizePolicy::SizeType hor, QSizePolicy::SizeType ver, bool hfw = FALSE );
     virtual int heightForWidth(int) const;
 
+    QRegion	clipRegion() const;
+
 // ### move together with other slots in Qt 4.0
 public slots:
     virtual void  	adjustSize();
@@ -572,6 +577,7 @@ private:
     friend void qt_clean_root_win();
     friend bool qt_recreate_root_win();
     friend QPoint posInWindow(QWidget *);
+    friend bool qt_mac_update_sizer(QWidget *, int);
     friend QWidget *qt_recursive_match(QWidget *widg, int x, int y);
     friend bool qt_paint_children(QWidget *,QRegion &, uchar ops);
     friend QMAC_PASCAL OSStatus qt_window_event(EventHandlerCallRef er, EventRef event, void *);
@@ -621,6 +627,7 @@ private:
     uint 	 in_show : 1;
     uint 	 in_show_maximized : 1;
     uint	 fstrut_dirty : 1;
+    uint	 im_enabled : 1;
     QRect	 crect;
     QColor	 bg_col;
 #ifndef QT_NO_PALETTE
@@ -800,10 +807,7 @@ inline void QWidget::update( const QRect &r )
 { update( r.x(), r.y(), r.width(), r.height() ); }
 
 inline void QWidget::repaint()
-{ repaint( 0, 0, crect.width(), crect.height(), TRUE ); }
-
-inline void QWidget::repaint( bool erase )
-{ repaint( 0, 0, crect.width(), crect.height(), erase ); }
+{ repaint( TRUE ); }
 
 inline void QWidget::repaint( const QRect &r, bool erase )
 { repaint( r.x(), r.y(), r.width(), r.height(), erase ); }
@@ -899,6 +903,11 @@ inline void QWidget::setSizePolicy( QSizePolicy::SizeType hor, QSizePolicy::Size
     setSizePolicy( QSizePolicy( hor, ver, hfw) );
 }
 
+inline bool QWidget::isInputMethodEnabled() const
+{
+    return (bool)im_enabled;
+}
+
 // Extra QWidget data
 //  - to minimize memory usage for members that are seldom used.
 //  - top-level widgets have extra extra data to reduce cost further
@@ -940,6 +949,7 @@ struct Q_EXPORT QTLWExtra {
 #if defined(Q_WS_MAC)
     WindowGroupRef group;
     uint     is_moved: 1;
+    uint     resizer : 4;
 #endif
 #if defined(Q_WS_QWS) && !defined ( QT_NO_QWS_MANAGER )
     QRegion decor_allocated_region;		// decoration allocated region
@@ -979,12 +989,13 @@ struct Q_EXPORT QWExtra {
     uint child_dirty : 1, child_serial : 15;
 #ifndef QMAC_NO_QUARTZ
     uint ctx_children_clipped:1;
-#endif
+#endif // QMAC_NO_QUARTZ
     uint has_dirty_area:1;
-#endif
+#endif // Q_WS_MAC
     uint bg_origin : 2;
 #if defined(Q_WS_X11)
     uint children_use_dnd : 1;
+    uint compress_events : 1;
 #endif
 #if defined(Q_WS_QWS) || defined(Q_WS_MAC)
     QRegion mask;				// widget mask
@@ -998,9 +1009,7 @@ struct Q_EXPORT QWExtra {
     QSizePolicy size_policy;
 };
 
-
-#ifdef QT_QWINEXPORT
 #define Q_DEFINED_QWIDGET
 #include "qwinexport.h"
-#endif /* QT_QWINEXPORT */
+
 #endif // QWIDGET_H
