@@ -1,5 +1,5 @@
 /****************************************************************************
-** $Id: qt/qpopupmenu.cpp   3.2.2   edited Jun 26 18:34 $
+** $Id: qt/qpopupmenu.cpp   3.2.3   edited Nov 8 16:17 $
 **
 ** Implementation of QPopupMenu class
 **
@@ -302,13 +302,19 @@ QPopupMenu::QPopupMenu( QWidget *parent, const char *name )
 
 QPopupMenu::~QPopupMenu()
 {
-    if ( syncMenu == this ) {
+    if ( syncMenu == this && qApp ) {
 	qApp->exit_loop();
 	syncMenu = 0;
     }
+
     if(d->scroll.scrolltimer)
 	delete d->scroll.scrolltimer;
 
+    if ( isVisible() ) {
+        parentMenu = 0;
+        hidePopups();
+    }
+
     delete (QWidget*) QMenuData::d->aWidget;  // tear-off menu
 
     preventAnimation = FALSE;
@@ -1120,7 +1126,7 @@ void QPopupMenu::updateSize()
 		    height = d->scroll.scrollableSize - scrheight;
 		    break;
 		}
-	    } 
+	    }
 	} else if( height + 2*frameWidth() >= dh ) {
 	    ncols++;
 	    max_height = QMAX(max_height, height - itemHeight);
@@ -1752,7 +1758,7 @@ void QPopupMenu::mouseMoveEvent( QMouseEvent *e )
 	    return;
 	}
 
-	if ( mi->popup() || ( popupActive >= 0 && popupActive != item )) 
+	if ( mi->popup() || ( popupActive >= 0 && popupActive != item ))
 	    popupSubMenuLater( style().styleHint(QStyle::SH_PopupMenu_SubMenuPopupDelay, this),
 			       this );
 	else if ( singleSingleShot )
@@ -2020,7 +2026,7 @@ void QPopupMenu::keyPressEvent( QKeyEvent *e )
 	while ( top->parentMenu )
 	    top = top->parentMenu;
 	if ( top->isMenuBar ) {
-	    int beforeId = top->actItem; 
+	    int beforeId = top->actItem;
 	    ((QMenuBar*)top)->tryKeyEvent( this, e );
 	    if ( beforeId != top->actItem )
 		ok_key = TRUE;
@@ -2113,7 +2119,7 @@ void QPopupMenu::keyPressEvent( QKeyEvent *e )
     }
 
 #ifdef Q_OS_WIN32
-    if ( !ok_key && 
+    if ( !ok_key &&
 	!( e->key() == Key_Control || e->key() == Key_Shift || e->key() == Key_Meta ) )
 	qApp->beep();
 #endif // Q_OS_WIN32
