@@ -8,10 +8,16 @@
 ** Foundation and appearing in the file LICENSE.GPL included in the
 ** packaging of this file.
 **
+** Licensees holding valid Qt Enterprise Edition or Qt Professional Edition
+** licenses may use this file in accordance with the Qt Commercial License
+** Agreement provided with the Software.
+**
 ** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 ** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 **
 ** See http://www.trolltech.com/gpl/ for GPL licensing information.
+** See http://www.trolltech.com/pricing.html or email sales@trolltech.com for
+**   information about Qt Commercial License Agreements.
 **
 ** Contact info@trolltech.com if any conditions of this licensing are
 ** not clear to you.
@@ -32,6 +38,7 @@
 #include "orderindicator.h"
 #include "hierarchyview.h"
 #include "designerappiface.h"
+#include "menubareditor.h"
 #define NO_STATIC_COLORS
 #include "globaldefs.h"
 
@@ -60,6 +67,7 @@
 #include <qaccel.h>
 #include <qpixmapcache.h>
 #include <qbitmap.h>
+#include <qsplitter.h>
 
 // FormWindow should be able to work to some limited degree
 // (existance, loading) without a MainWindow. Functions which require
@@ -75,7 +83,7 @@ static void setCursorToAll( const QCursor &c, QWidget *start )
     QObjectList *l = (QObjectList*)start->children();
     if ( l ) {
 	for ( QObject *o = l->first(); o; o = l->next() ) {
-	    if ( o->isWidgetType() && !o->inherits( "SizeHandle" ) )
+	    if ( o->isWidgetType() && !::qt_cast<SizeHandle*>(o) )
 		setCursorToAll( c, ( (QWidget*)o ) );
 	}
     }
@@ -90,7 +98,7 @@ static void restoreCursors( QWidget *start, FormWindow *fw )
     QObjectList *l = (QObjectList*)start->children();
     if ( l ) {
 	for ( QObject *o = l->first(); o; o = l->next() ) {
-	    if ( o->isWidgetType() && !o->inherits( "SizeHandle" ) )
+	    if ( o->isWidgetType() && !::qt_cast<SizeHandle*>(o) )
 		restoreCursors( ( (QWidget*)o ), fw );
 	}
     }
@@ -177,7 +185,7 @@ void FormWindow::init()
 	     this, SIGNAL( undoRedoChanged( bool, bool, const QString &, const QString & ) ) );
     propShowBlocked = FALSE;
 
-    setIcon( QPixmap::fromMimeSource( "form.png" ) );
+    setIcon( QPixmap::fromMimeSource( "designer_form.png" ) );
 
     connect( &commands, SIGNAL( modificationChanged( bool ) ),
 	     this, SLOT( modificationChanged( bool ) ) );
@@ -357,7 +365,7 @@ void FormWindow::insertWidget()
     if ( !savePixmapInline() && currTool == WidgetDatabase::idFromClassName( "PixmapLabel" ) ) { // ### what to do for pixmaps in project
 	QPixmap pix;
 	// we have to force the pixmap to get a new and unique serial number. Unfortunately detatch() doesn't do that
-	pix.convertFromImage( QPixmap::fromMimeSource( "image.png" ).convertToImage() );
+	pix.convertFromImage( QPixmap::fromMimeSource( "designer_image.png" ).convertToImage() );
 	( (QLabel*)w )->setPixmap( pix );
     }
     int id = WidgetDatabase::idFromClassName( WidgetFactory::classNameOf(w) );
@@ -526,8 +534,7 @@ void FormWindow::handleContextMenu( QContextMenuEvent *e, QWidget *w )
 		    ( WidgetFactory::layoutType( w->parentWidget()) != WidgetFactory::NoLayout ||
 		      !insertedWidgets.find(w) ) )
 		w = w->parentWidget();
-	    if ( mainContainer()->inherits( "QMainWindow" ) &&
-		 ( (QMainWindow*)mainContainer() )->centralWidget() == realWidget ) {
+	    if ( ::qt_cast<QMainWindow*>(mainContainer()) && ((QMainWindow*)mainContainer())->centralWidget() == realWidget ) {
 		e->accept();
 		mainwindow->popupFormWindowMenu( e->globalPos(), this );
 	    } else {
@@ -639,7 +646,7 @@ void FormWindow::handleMousePress( QMouseEvent *e, QWidget *w )
 	    break;
 	validForBuddy = FALSE;
 	if ( currTool == BUDDY_TOOL ) {
-	    if ( !w->inherits( "QLabel" ) )
+	    if ( !::qt_cast<QLabel*>(w) )
 		break;
 	    clearSelection( FALSE );
 	    validForBuddy = TRUE;
@@ -681,7 +688,7 @@ void FormWindow::handleMousePress( QMouseEvent *e, QWidget *w )
 		for (;;) {
 		    int id = WidgetDatabase::idFromClassName( WidgetFactory::classNameOf( wid ) );
 		    if ( ( WidgetDatabase::isContainer( id ) || wid == mainContainer() ) &&
-			 !wid->inherits( "QLayoutWidget" ) && !wid->inherits( "QSplitter" ) ) {
+			 !::qt_cast<QLayoutWidget*>(wid) && !::qt_cast<QSplitter*>(wid) ) {
 			insertParent = WidgetFactory::containerOfWidget( wid ); // found another parent, store it
 			break;
 		    } else {
@@ -848,8 +855,7 @@ void FormWindow::handleMouseMove( QMouseEvent *e, QWidget *w )
 	    wid = designerWidget( wid );
 	if ( wid && ( isMainContainer( wid ) || insertedWidgets.find( wid ) ) && wid->isVisibleTo( this ) )
 	    newendWidget = wid;
-	if ( newendWidget &&
-	     ( newendWidget->inherits( "QLayoutWidget" ) || newendWidget->inherits( "Spacer" ) ) )
+	if ( ::qt_cast<QLayoutWidget*>(newendWidget) || ::qt_cast<Spacer*>(newendWidget) )
 	    newendWidget = (QWidget*)endWidget;
 	drawRecRect = newendWidget != endWidget;
 	if ( newendWidget &&
@@ -875,8 +881,7 @@ void FormWindow::handleMouseMove( QMouseEvent *e, QWidget *w )
 	    newendWidget = wid;
 	else
 	    newendWidget = 0;
-	if ( newendWidget &&
-	     ( newendWidget->inherits( "QLayoutWidget" ) || newendWidget->inherits( "Spacer" ) ) )
+	if ( ::qt_cast<QLayoutWidget*>(newendWidget) || ::qt_cast<Spacer*>(newendWidget) )
 	    newendWidget = (QWidget*)endWidget;
 	drawRecRect = newendWidget != endWidget;
 	if ( !newendWidget )
@@ -962,13 +967,12 @@ void FormWindow::handleMouseRelease( QMouseEvent *e, QWidget *w )
 		bool emitSelChanged = FALSE;
 		for ( QMap<ulong, QPoint>::Iterator it = moving.begin(); it != moving.end(); ++it ) {
 		    QWidget *i = (QWidget*)it.key();
-		    if ( !emitSelChanged && i->inherits( "QButton" )  ) {
-			if ( i->parentWidget() && i->parentWidget()->inherits( "QButtonGroup" ) ||
-			     wa->inherits( "QButtonGroup" ) )
+		    if ( !emitSelChanged && ::qt_cast<QButton*>(i) ) {
+			if ( ::qt_cast<QButtonGroup*>(i->parentWidget()) || ::qt_cast<QButtonGroup*>(wa) )
 			    emitSelChanged = TRUE;
-			if ( !wa->inherits( "QButtonGroup" ) ) {
+			if ( !::qt_cast<QButtonGroup*>(wa) ) {
 			    MetaDataBase::setPropertyChanged( i, "buttonGroupId", FALSE );
-			    if ( i->parentWidget() && i->parentWidget()->inherits( "QButtonGroup" ) )
+			    if ( ::qt_cast<QButtonGroup*>(i->parentWidget()) )
 				( (QButtonGroup*)i->parentWidget() )->remove( (QButton*)i );
 			}
 		    }
@@ -1180,8 +1184,7 @@ void FormWindow::selectWidget( QObject *o, bool select )
 	return;
     }
 
-    if ( mainContainer()->inherits( "QMainWindow" ) &&
-	 w == ( (QMainWindow*)mainContainer() )->centralWidget() ) {
+    if ( ::qt_cast<QMainWindow*>(mainContainer()) && w == ( (QMainWindow*)mainContainer() )->centralWidget() ) {
 	QObject *opw = propertyWidget;
 	propertyWidget = mainContainer();
 	if ( opw->isWidgetType() )
@@ -1190,7 +1193,7 @@ void FormWindow::selectWidget( QObject *o, bool select )
 	return;
     }
 
-    if ( o->inherits( "QDesignerToolBar" ) || o->inherits( "QDesignerMenuBar" ) )
+    if ( ::qt_cast<QDesignerToolBar*>(o) )
 	return;
 
     if ( select ) {
@@ -1863,7 +1866,7 @@ void FormWindow::lowerWidgets()
     commandHistory()->addCommand( cmd );
 }
 
-static void find_accel( const QString &txt, QMap<QChar, QWidgetList > &accels, QWidget *w )
+void find_accel( const QString &txt, QMap<QChar, QWidgetList > &accels, QWidget *w )
 {
     int i = txt.find( "&" );
     if ( i == -1 )
@@ -1905,6 +1908,8 @@ void FormWindow::checkAccels()
 		    find_accel( w->property( "title" ).toString(), accels, w );
 		if ( pageTitle )
 		    find_accel( w->property( "pageTitle" ).toString(), accels, w );
+	    } else if ( ::qt_cast<MenuBarEditor*>(o) ) {
+		((MenuBarEditor *)o)->checkAccels( accels );
 	    }
 	}
 	delete l;
@@ -2112,7 +2117,7 @@ void FormWindow::breakLayout( QWidget *w )
 	    Command *cmd = breakLayoutCommand( w );
 	    if ( cmd )
 		commands.insert( 0, cmd );
-	    if ( !w->inherits( "QLayoutWidget" ) && !w->inherits( "QSplitter" ) )
+	    if ( !::qt_cast<QLayoutWidget*>(w) && !::qt_cast<QSplitter*>(w) )
 		break;
 	}
 	w = w->parentWidget();
@@ -2218,7 +2223,7 @@ void FormWindow::saveBackground()
 
 void FormWindow::restoreConnectionLine()
 {
-    if (!unclippedPainter)
+    if (!unclippedPainter || !buffer) // designer will occasionally crash if buffer is not tested to be non-zero
 	return;
 
     int a =QABS( startPos.x() - currentPos.x() );
@@ -2275,7 +2280,7 @@ void FormWindow::restoreConnectionLine()
 
 void FormWindow::restoreRect( const QRect &rect )
 {
-    if (!unclippedPainter)
+    if (!unclippedPainter || !buffer)
 	return;
 
     QRect r( rect );
@@ -2375,7 +2380,7 @@ bool FormWindow::unify( QObject *w, QString &s, bool changeIt )
 		}
 	    }
 	}
-	if ( mainContainer()->inherits( "QMainWindow" ) ) {
+	if ( ::qt_cast<QMainWindow*>(mainContainer()) ) {
 	    if ( !found ) {
 		QObjectList *l = mainContainer()->queryList( "QDockWindow", 0, TRUE );
 		for ( QObject *o = l->first(); o; o = l->next() ) {
@@ -2390,20 +2395,6 @@ bool FormWindow::unify( QObject *w, QString &s, bool changeIt )
 		}
 		delete l;
 	    }
-	    if ( !found ) {
-		QObjectList *l = mainContainer()->queryList( "QDesignerPopupMenu", 0, TRUE );
-		for ( QObject *o = l->first(); o; o = l->next() ) {
-		    if ( o != w &&
-			 qstrcmp( o->name(), s.latin1() ) == 0 ) {
-			found = TRUE;
-			if ( !changeIt )
-			    break;
-			s = orig + "_" + QString::number( ++num );
-			o = l->first();
-		    }
-		}
-		delete l;
-	    }
 	}
     }
 
@@ -2513,9 +2504,8 @@ QWidget *FormWindow::containerAt( const QPoint &pos, QWidget *notParentOf )
     }
 
     for ( ; it.current(); ++it ) {
-	if ( it.current()->inherits( "QLayoutWidget" ) )
-	    continue;
-	if ( it.current()->inherits( "QSplitter" ) )
+	if ( ::qt_cast<QLayoutWidget*>(it.current())
+	  || ::qt_cast<QSplitter*>(it.current()) )
 	    continue;
 	if ( !it.current()->isVisibleTo( this ) )
 	    continue;
@@ -2672,7 +2662,7 @@ DesignerFormWindow *FormWindow::iFace()
 
 bool FormWindow::isCentralWidget( QObject *w ) const
 {
-    if ( !mainContainer()->inherits( "QMainWindow" ) )
+    if ( !::qt_cast<QMainWindow*>(mainContainer()) )
 	return FALSE;
     return w == ( (QMainWindow*)mainContainer() )->centralWidget();
 }
